@@ -17,12 +17,14 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <stdio.h>
 #include <string.h>
 #include <gtk/gtk.h>
-#include <gtk/gtkwidget.h>
 #include <sys/types.h>
-#include <bonobo.h>
 
 #include "accessible-image-view.h"
 #include "eog-scroll-view.h"
